pub(super) struct ExtractIfInner<'a, K, V, R> {
length: &'a mut usize,
dormant_root: Option<DormantMutRef<'a, NodeRef<Owned, K, V, LeafOrInternal>>>,
cur_leaf_edge: Option<Handle<NodeRef<Mut<'a>, K, V, Leaf>, Edge>>,
range: R,
}Expand description
Most of the implementation of ExtractIf are generic over the type of the predicate, thus also serving for BTreeSet::ExtractIf.
Fields
length: &'a mut usizeReference to the length field in the borrowed map, updated live.
dormant_root: Option<DormantMutRef<'a, NodeRef<Owned, K, V, LeafOrInternal>>>Buried reference to the root field in the borrowed map.
Wrapped in Option to allow drop handler to take it.
cur_leaf_edge: Option<Handle<NodeRef<Mut<'a>, K, V, Leaf>, Edge>>Contains a leaf edge preceding the next element to be returned, or the last leaf edge. Empty if the map has no root, if iteration went beyond the last leaf edge, or if a panic occurred in the predicate.
range: RRange over which iteration was requested. We don’t need the left side, but we can’t extract the right side without requiring K: Clone.
Implementations
Sourceimpl<'a, K, V, R> ExtractIfInner<'a, K, V, R>
impl<'a, K, V, R> ExtractIfInner<'a, K, V, R>